#' @importFrom BBmisc stopf
#' @importFrom BBmisc warningf
#' @importFrom BBmisc collapse
#' @importFrom BBmisc %nin%
#' @importFrom BBmisc is.error
#' @importFrom BBmisc setClasses
#' @importFrom BBmisc isDirectory

UNITCONVERT = setNames(c(1L, 1024L, 1048576L, 1073741824L), c("b", "kB", "Mb", "Gb"))